### Name: closedpCI
### Title: Customization of a Loglinear Model and profile Likelihood
###   Confidence Interval for Abundance Estimation in Closed Population
###   Capture-Recapture Experiments
### Aliases: closedpCI closedpCI.t closedpCI.0 print.closedpCI plotCI
###   plotCI.closedpCI boxplot.closedpCI plot.closedpCI
### Keywords: models

### ** Examples

data(hare)
CI<-closedpCI.t(hare, m = "Mth", h = "Poisson", theta = 2)
CI
plotCI(CI)

data(HIV)
mat<-histpos.t(4)
mX2<-cbind(mat,mat[,1]*mat[,2])
closedpCI.t(HIV,dfreq=TRUE,mX=mX2,mname="Mt interaction 1,2")

data(BBS2001)
CI0<-closedpCI.0(BBS2001,dfreq=TRUE,dtype="nbcap",t=50,t0=20,
                 m="Mh",h="Gamma",theta=3.5)
CI0
plot(CI0)
plotCI(CI0)

### As an alternative to a gamma model, one can fit a negative Poisson model.
### It is appropriate in experiments where very small capture probabilities
### are likely. It can lead to very large estimators of abundance. 
data(mvole)
period3<-mvole[,11:15]
psi <- function(x) { 0.5^x - 1 }
closedpCI.t(period3, m = "Mh", h = psi)



